@@ -1,5 +1,5 @@
 "Inherit Slides class from here. It adds useful attributes and methods."
-import os, re, textwrap
+import os, re, textwrap, json
 import traceback
 from pathlib import Path
 from contextlib import ContextDecorator
@@ -78,13 +78,14 @@ class BaseSlides:
          `zoom-child`       | Zooms child object on hover, when Zoom is enabled.
          `no-zoom`          | Disables zoom on object when it is child of 'zoom-child'.
         
-        Besides these CSS classes, you always have `Slide.set_css`, `Slides.html('style',...) functions at your disposal.
+        Besides these CSS classes, you always have `Slide.set_css`, `Slides.html('style',...)` functions at your disposal.
         ''',returns = True))
 
     @property
     def xmd_syntax(self):
         "Special syntax for markdown."
-        return XTML(self.parse(textwrap.dedent(rf'''
+        with self._hold_running():
+            return XTML(self.parse(textwrap.dedent(rf'''
         **Extended Markdown**{{.text-large}}
                                                
         Extended syntax for markdown is constructed to support almost full presentation from Markdown.
@@ -99,13 +100,15 @@ class BaseSlides:
         Double dashes `--` is used to split text in frames. Alongwith this `%++` can be used to increment text on framed slide.
         
         Citations
-        : - alert`cite\`key1,key2\``/alert`\@key1,\@key2` to add citation to current slide. citations are automatically added in suitable place and should be set once using `Slides.set_citations` function (or see below).
+        : - alert`cite\`key1,key2\`` / alert`\@key1,\@key2` to add citation to current slide. citations are automatically added in suitable place and should be set once using `Slides.set_citations` function (or see below).
         - With citations mode set as 'footnote', you can add alert`refs\`ncol_refs\`` to add citations anywhere on slide. If `ncol_refs` is not given, it will be picked from layout settings.
+        - Force a citation to be shown inline by appending a ! even in footnote mode, such as alert`\@key!`.
         - In the synced markdown file (also its included files) through `Slides.sync_with_file`, you can add citations with block sytnax:                             
-        <code>\\`\\`\\`citations [inline or footnote]
-        @key1: Saboor et. al., 2025
-        @key2: A citations can span multiple lines, but key should start on new line
-        \\`\\`\\`</code>
+        hl["markdown"]`
+        \`\`\`citations [inline or footnote]
+        \@key1: Saboor et. al., 2025
+        \@key2: A citations can span multiple lines, but key should start on new line
+        \`\`\``
         
         Sections & TOC
         : alert`section\`content\`` to add a section that will appear in the table of contents.
@@ -128,7 +131,7 @@ class BaseSlides:
                 - Markdown enclosed in hl`fmt(content, **vars)` will not expose encapsulated `vars` for updates later, like static stuff but useful inside python scripts to pick local scope variable.
                 - In summary, variables are resolved by scope in the prefrence `rebuild > __main__`. Outer scope variables are overwritter by inner scope variables.
             - Use unique variable names on each slide to avoid accidental overwriting during update.
-            - Varibales used as attributes like `\%{{var.attr}}` and indexing like `\%{{var[0]}}`/`\%{{var["key"]}}` will be update only if `var` itself is changed.
+            - Varibales used as attributes like `\%{{var.attr}}` and indexing like `\%{{var[0]}}` / `\%{{var["key"]}}` will be update only if `var` itself is changed.
 
         ::: note-warning
             alert`\%{{variable:nb}}` breaks the DOM flow, e.g. if you use it inside heading, you will see two headings above and below it with splitted text. Its fine to use at end or start or inside paragraph.                                    
@@ -136,33 +139,31 @@ class BaseSlides:
         ::: note-info
             - Widgets behave same with or without `:nb` format spec. 
             - Formatting is done using `str.format` method, so f-string like literal expressions are not supported, but you don't need to supply variables, just enclose text in `Slides.fmt`.
-            - Variables are substituted from top level scope (Notebook's hl`locals()`/hl`globals()`). To use variables from a nested scope, use `Slides.fmt`.
+            - Variables are substituted from top level scope (Notebook's hl`locals()` / hl`globals()`). To use variables from a nested scope, use `Slides.fmt`.
         
         - Cells in markdown table can be spanned to multiple rows/columns by attributes | cell text \{{: rowspan="2" colspan="1"}}| inside a cell, should be a space bewteen text and attributes.
-        - A syntax alert`func\`?Markdown?\`` will be converted to alert`func\`Parsed HTML\`` in markdown. Useful to nest special syntax.
         - Escape a backtick with \\, i.e. alert`\\\` → \``. In Python >=3.12, you need to make escape strings raw, including the use of $ \LaTeX $ and re module.
-        - alert`include\`markdown_file.md\`` to include a file in markdown format. These files are watched for eidts if included in synced markdown file via `Slides.sync_with_file`.
-        - Inline columns/rows can be added by using alert`stack\`Column A | Column B\`` sytnax with `?` next to opening \\` and before closing \\` most of the time to properly parse inner markdown. You can escape pipe `|` with `\|` to use it as text inside stack.
+        - alert`include\`markdown_file.md[optional list slicing to pick lines from file such as [2:5], [10:]]\`` to include a file in markdown format. These files are watched for eidts if included in synced markdown file via `Slides.sync_with_file`.
+        - Inline columns/rows can be added by using alert`stack\`Column A || Column B\`` sytnax. You can escape pipe `|` with `\|` to use it as text inside stack. See at end how to nest such stacking.
         - Block multicolumns are made using follwong syntax, column separator is triple plus `+++`:
         
-        ```markdown     
-         ```multicol widthA widthB .class1.class2
-         Column A
-         +++
-         Column B
-         ```
+        ```md-left
+            ```multicol 2 3 .block-blue
+                ```md-after
+                ## Column A
+                ```
+            +++
+                ## Column B
+                ```multicol .block-red
+                **Nested Column A**{{: .block-green}}
+                +++
+                **Nested Column B**{{: .block-yellow}}
+                ```
+            ```
         ```
         
         - Definition list syntax:
-        ```multicol 30 10 30 30 .block-red
-            Item 1 Header
-            : Item 1 details
-        
-            Item 1 Header
-            : Item 1 details
-        +++
-        vspace`4`👉
-        +++
+        ```md-left
         Item 1 Header
         : Item 1 details
 
@@ -170,6 +171,7 @@ class BaseSlides:
         : Item 1 details
         ```
         
+        - `md-[left,right,before,after]` and `multicol` support nesting via proper indentation, but it may be broken by display contexts. 
         - Code blocks syntax highlighting. (there is an inline highlight syntax as well alert`hl\`code\``)
         
         ```python
@@ -177,12 +179,7 @@ class BaseSlides:
         ```     
                                                                               
         - A whole block of markdown can be CSS-classed using syntax
-        ```multicol 30 10 30 30 .block-blue
-            ::: block-yellow
-                Some **bold text**
-        +++
-        vspace`2`👉
-        +++
+        ```md-left -c
         ::: block-yellow
             Some **bold text**
         ```
@@ -199,6 +196,18 @@ class BaseSlides:
             - You can serialize custom python objects to HTML using `Slides.serializer` function. Having a 
                 `__format__` method in your class enables to use {{obj}} syntax in python formatting and \%{{obj}} in extended Markdown.
         
+        - Upto 4 level nesting is parsed using (level + 1) number of alert`/` (at least two) within backticks in functions given below. 
+        ```md-left -c
+        stack[(6,4),css_class="block-blue"]`////
+            This always parse markdown in `returns=True` mode and is equivalent to markdown customblocks. ||
+            stack[css_class="info"]`/// B || A
+                stack[vertical=True]`// C ||
+                    stack[css_class="block-red"]` D || E ` 
+                //` 
+            ///` 
+        ////`
+        ```
+        
         - Other options (that can also take extra args [python code as strings] as alert`func[arg1,x=2,y=A]\`arg0\``) include:
         ''') + '\n' + ',\n'.join(rf'    - alert`{k}`\\`{v}\\`' for k,v in _special_funcs.items()),
         returns = True
@@ -254,18 +263,8 @@ class BaseSlides:
         content, fmt_kws = fmt._astuple(content) # fmt used on top level, or string means no keywords
         content = re.split(r'^\s*EOF\s*$',content, flags = re.MULTILINE)[0]
 
-        if synced and (refs_matches := re.findall(
-            r'```citations(.*?)\n```', content, flags= re.DOTALL | re.MULTILINE
-            )):
-            if len(refs_matches) != 1:
-                raise ValueError(f"Only a single block of citations is allowed, found {len(refs_matches)} blocks {refs_matches}")
-            
-            # Citations block will itself be remove during parsing slide
-            # We need to keep here to compare changes, otherwise it cannot detect
-            mode, refs = [line.strip() for line in refs_matches[0].split('\n',1)] # should be ```citations mode and then below
-            if not mode:
-                mode = self._cite_mode # keep same
-            self.set_citations(refs, mode=mode)
+        if synced:
+            content = self._process_citations(content)
 
         if any(map(lambda v: '\n---' in v, # I gave up on single regex after so much attempt
             (re.findall(r'```multicol(.*?)\n```', content, flags=re.DOTALL | re.MULTILINE) or [''])
@@ -286,6 +285,21 @@ class BaseSlides:
         # Return refrence to slides for quick update
         return handles
     
+    def _process_citations(self, content):
+        match1, *others = re.findall(r'```citations(.*?)\n```', content, flags= re.DOTALL | re.MULTILINE)
+        if others:
+            raise ValueError(f"Only a single block of citations is parsed, found {len(others) + 1} blocks")
+            
+        content = content.replace(f'```citations{match1}\n```','') # clean up
+        if getattr(self,'_bib_md','') != match1:
+            self._bib_md = match1 # set for next test
+
+            mode, refs = [line.strip() for line in match1.split('\n',1)] # should be ```citations mode and then below
+            if not mode:
+                mode = self._cite_mode # keep same
+            self.set_citations(refs, mode=mode)
+        return content
+    
     def sync_with_file(self, start_slide_number, /, path, interval=500):
         r"""Auto update slides when content of markdown file changes. You can stop syncing using `Slides.unsync` function.
         interval is in milliseconds, 500 ms default. Read `Slides.build` docs about content of file.
@@ -293,7 +307,15 @@ class BaseSlides:
         The variables inserted in file content are used from top scope.
 
         You can add files inside linked file using include\\`file_path.md\\` syntax, which are also watched for changes.
-        This helps modularity of content, and even you can link a citation file in markdown format. Read more in `Slides.xmd_syntax` about it.
+        This helps modularity of content, and even you can link a citation file in markdown format as shown below. Read more in `Slides.xmd_syntax` about it.
+
+        ```markdown
+         ```citations footnote
+         @key1: Saboor et. al., 2025
+         @key2: A citations can span multiple lines, but key should start on new line
+         <!-- Or put this content in a file 'bib.md' and then inside citations block use include`bib.md` -->
+         ```
+        ```
         
         ::: note-tip
             To debug the linked file or included file, use EOF on its own line to keep editing and clearing errors.
@@ -331,7 +353,6 @@ class BaseSlides:
                         included_files.update(
                             map(Path, re.findall(r'include\`(.*?)\`',content, flags = re.DOTALL))
                         ) 
-                        print(included_files)
                         self._from_markdown(start, 
                             resolve_included_files(content), # add included file text to be detected for changes
                             synced=True # only one citation block allowed for consistency
@@ -340,7 +361,7 @@ class BaseSlides:
                         self._unregister_postrun_cell() # No cells buttons from inside file code run
                     except:
                         e, text = traceback.format_exc(limit=0).split(':',1) # only get last error for notification
-                        self.notify(f"{error('SyncError','something went wrong')}<br/><br/>{error(e,text)}",20)
+                        self.notify(f"{error('SyncError','something went wrong')}<br/>{error(e,text)}",20)
             else:
                 self.notify(error("SyncError", f"file {path!r} no longer exists!").value, 20)
         
@@ -369,7 +390,7 @@ class BaseSlides:
         2. hl`with slides.build(number):` creates single slide. Equivalent to hl`%%slide number` magic.
             - Use hl`fsep()` from top import or hl`Slides.fsep()` to split content into frames.
             - Use hl`for item in fsep.iter(iterable):` block to automatically add frame separator.
-            - Use hl`fsep(True)`/hl`fsep.iter(...,stack=True)` to join content of frames incrementally.
+            - Use hl`fsep(True)` / hl`fsep.iter(...,stack=True)` to join content of frames incrementally.
         3. hl`slides.build(number, str | fmt)` creates many slides with markdown content. Equivalent to hl`%%slide number -m` magic in case of one slide.
             - Frames separator is double dashes `--` and slides separator is triple dashes `---`. Same applies to hl`Slides.sync_with_file` too.
             - Use `%++` to join content of frames incrementally.
@@ -451,7 +472,7 @@ class BaseSlides:
         from ..core import Slides
 
         self.set_citations({'A': 'Citation A', 'B': 'Citation B'}, mode = 'footnote')
-        self.settings.footer(text='IPySlides Documentation', date=None)
+        self.settings.footer(text=self.get_logo("1em") + "IPySlides Documentation", date=None)
 
         with self.build(0): # Title page
             self.this.set_bg_image(self.get_logo(),0.25, filter='blur(10px)', contain=True)
@@ -469,20 +490,15 @@ class BaseSlides:
                 ''', logo = self.get_logo("4em"))).display()
         
         self.build(-1, self.fmt('''
-            section`Introduction` 
-            ```multicol .block-green
-            toc[True]`## Table of contents`
-            +++
-            ### This is summary of current section
-            Oh we can use inline columns stack`Column A | Column B` here and what not!
-            %{btn}
-            ```
-            ```markdown
-             ```multicol .block-green
-             toc[True]`## Table of contents`
-             +++
-             Extra content for current section which is on right
-             ```
+            ```md-after
+                section`Introduction` 
+                ```multicol .block-green
+                toc[True]`## Table of contents`
+                +++
+                ### This is summary of current section
+                Oh we can use inline columns stack`Column A || Column B` here and what not!
+                %{btn}
+                ```
             ```''', btn = self.draw_button))
             
         with self.build(-1):
@@ -511,26 +527,26 @@ class BaseSlides:
             self.doc(self[0], members='yoffset set_animation set_bg_image update_display get_source show set_css'.split(), itself = False).display()
             self.css_syntax.display()
         
-        with self.build(-1), self.code.context():
-            # self is in scope, auto picked, also fmt can be parsed on display
-            display(self.fmt('%{self.version!r} %{self.xmd_syntax}'))
+        with self.build(-1):
+            self.xmd_syntax.display()
             
         with self.build(-1):
             self.write('## Adding Content')
             self.write('Besides functions below, you can add content to slides with `%%xmd`,`%xmd` as well.\n{.note .info}')
-            self.write([self.styled(self.doc(self.write,'Slides'),'block-green'), self.doc(self.parse,'Slides')])
+            self.write(self.doc(self.write,'Slides'), [self.doc(self.parse,'Slides'),self.doc(self.as_html,'Slides'),self.doc(self.html,'Slides')])
         
         with self.build(-1):
             self.write('## Adding Speaker Notes')
-            self.write([rf'You can use alert`notes\`notes content\`` in markdown.\n{{.note .success}}\n',
+            self.write([rf'styled["note success"]`You can use alert`notes\`notes content\`` in markdown.`',
                        'This is experimental feature, and may not work as expected.\n{.note-error .error}'])
             self.doc(self.notes,'Slides.notes', members = True, itself = False).display()
                    
         with self.build(-1):
             self.write('## Displaying Source Code')
+            self.write('In markdown, the block `md-[before,after,left,right] [-c]` parses and displays source as well.')
             self.doc(self.code,'Slides.code', members = True, itself = False).display()
         
-        self.build(-1, 'section`?Layout and color["yellow","black"]`Theme` Settings?` toc`### Contents`')
+        self.build(-1, r'section`//Layout and color["yellow","black"]`Theme` Settings//` toc`### Contents`')
         
         with self.build(-1) as s:
             s.set_css({
@@ -541,7 +557,7 @@ class BaseSlides:
             self.doc(self.settings,'Slides', members=True,itself = True).display()
                 
         with self.build(-1):
-            self.write('## Useful Functions for Rich Content section`?Useful Functions for alert`Rich Content`?`')
+            self.write('## Useful Functions for Rich Content section`//Useful Functions for alert`Rich Content`//`')
             self.doc(self.alt,'Slides').display()
             
             members = sorted((
@@ -554,7 +570,7 @@ class BaseSlides:
         with self.build(-1):
             self.write(r'''
                 ## Citations and Sections
-                Use syntax alert`cite\`key\``/alert`\@key` to add citations which should be already set by hl`Slides.set_citations(data, mode)` method.
+                Use syntax alert`cite\`key\`` / alert`\@key` to add citations which should be already set by hl`Slides.set_citations(data, mode)` method.
                 Citations are written on suitable place according to given mode. Number of columns in citations are determined by 
                 hl`Slides.settings.layout(..., ncol_refs = int)`. @A
                        
@@ -587,18 +603,24 @@ class BaseSlides:
                     time = t.strftime('%H:%M:%S')
                     self.notify(f'Notification at {time} form slide {slide.index} and frame {slide.indexf}', timeout=5)
             
-            self.write(self.doc(self.ei.interact,'Slides.ei'), [*cap.outputs, c, self.doc(self.on_load,'Slides')])
+            self.write(
+                [self.doc(self.ei.interact,'Slides.ei')], 
+                [*cap.outputs, c, self.doc(self.on_load,'Slides')],
+            )
     
-        with self.build(-1):
-            self.write('## Content Styling')
-            with self.code.context(returns = True) as c:
-                self.write(('You can **style**{.error} or **color["teal"]`colorize`** your *content*{: style="color:hotpink;"} and *color["hotpink","yellow"]`text`*. ' 
-                       'Provide **CSS**{.info} for that using hl`Slides.html("style",...)` or use some of the available styles. '
-                       'See these **styles**{.success} with `Slides.css_styles` property as below:'))
-                self.css_styles.display()
-                c.display()
+        self.build(-1, fmt("""
+        ```md-after -c
+        stack[(3,7)]`//
+        ## Content Styling
+        You can **style**{.error} or **color["teal"]`colorize`** your *content*{: style="color:hotpink;"} and *color["hotpink","yellow"]`text`*.
+        Provide **CSS**{.info} for that using hl`Slides.html("style",...)` or use some of the available styles. 
+        See these **styles**{.success} with `Slides.css_styles` property as shown on right.
+        || %{self.css_styles}
+        //`     
+        ```
+        """))
         
-        s, *_ = self.build(-1, self.fmt('''
+        self.build(-1, self.fmt('''
         ## Highlighting Code
         [pygments](https://pygments.org/) is used for syntax highlighting cite`A`.
         You can **highlight**{.error} code using `highlight` function cite`B` or within markdown using code blocks enclosed with three backticks:
@@ -608,7 +630,7 @@ class BaseSlides:
         ```javascript
         import React, { Component } from "react";
         ```
-        **s is assigned variable to this slide**: %{s.source}
+        Source code of slide can be embeded via variable too: %{self.this.source}
         ''', self=self))
 
         
@@ -638,7 +660,7 @@ class BaseSlides:
                 ), # Can also do 'Slides.serilaizer.get_metadata(obj)' if registered
                 s.get_source(), widths = [1,3]
             )
-            self.write('If you need to serialize your own or third party objects not serialized by this module, you can use `@Slides.serializer.register` to serialize them to html.\n{.note .info}')
+            self.write('If you need to serialize your own or third party objects not serialized by this module, you can use `\@Slides.serializer.register` to serialize them to html.\n{.note .info}')
             self.doc(self.serializer,'Slides.serializer', members = True, itself = False).display()
             self.write('**You can also extend markdown syntax** using `markdown extensions`, ([See here](https://python-markdown.github.io/extensions/) and others to install, then use as below):')
             self.doc(self.extender,'Slides.extender', members = True, itself = False).display()
