@@ -61,17 +61,11 @@ class _Citation:
                     <span style="color:var(--accent-color);">{self._id}. </span>
                 </a>{_value}</div>"""
         else:
-            return f'<div class = "warning">Set value for cited key {self._key!r} and run again to clear warning!</div>'
+            return self.inline_value # Just error message
 
     @property
     def inline_value(self):
-        if _value := self._slide._app._citations.get(self._key, None):
-            return utils.textbox(_value.partition("<p>")[-1].rpartition("</p>")[0],
-                left="initial",
-                top="initial",
-            ).value
-        else:
-            return self.value
+        return self._slide._app._nocite(self._key)
         
 class Singleton(type):
     # Before Slides calss was made singleton by creating a global instance. 
@@ -413,7 +407,7 @@ class Slides(BaseSlides,metaclass=Singleton):
                 how_to_slide],sizes=[14,1, 85]).display()
         
         self._unregister_postrun_cell() # This also clears slides per cell
-        self.settings.footer._apply_change(None) # Reset
+        self.settings.footer.text = self.get_logo('14px') + ' IPySlides'
 
     def clear(self):
         "Clear all slides."
@@ -444,23 +438,40 @@ class Slides(BaseSlides,metaclass=Singleton):
         # Return string otherwise will be on different place, avoid newline here
         return f'<a href="#{key}" class="citelink"><sup id ="{key}-back" style="color:var(--accent-color) !important;">{cited._id}</sup></a>'
     
+    def _nocite(self, key): # @key! without adding to citations
+        if key in self._citations:
+            return utils.textbox(self._citations[key].partition("<p>")[-1].rpartition("</p>")[0],
+            left="initial",top="initial").value
+        return utils.error("KeyError",f"Set value for cited key {key!r} and build slide again!").value
+
+    
     def _set_ctns(self, d):
         # Here other formatting does not work for citations
         new_citations = {k: self.parse(v, returns = True) for k, v in d.items()}
-        if self._citations != new_citations: # same call again should not change anything
+        added = set(new_citations) - set(self._citations)
+        removed = set(self._citations) - set(new_citations)
+        changed = {k for k in (set(new_citations) & set(self._citations)) if self._citations[k] != new_citations[k]}
+        if changed := (added | removed | changed):
             self._citations = new_citations
-            self._set_unsynced() # will go synced after rerun
+            self._set_unsynced(changed) # will go synced after rerun
     
-    def _set_unsynced(self):
-        for slide in self.cited_slides:
+    def _set_unsynced(self, changed):
+        if changed is True:
+            req_update = self.cited_slides
+        elif isinstance(changed,set):
+            req_update = [s for s in self.cited_slides if changed & set(s._citations)]
+        else:
+            raise TypeError(f"changed should be True or set of keys, got {type(changed)}")
+        
+        for slide in req_update:
             if slide._markdown:
                 slide._rebuild(go_there=False)
             else:
                 slide._set_css_classes(add = 'Out-Sync') # will go synced after rerun
 
     def set_citations(self, data, mode='footnote'):
-        r"""Set citations from dictionary or string with content like `@key: citation value` on their own lines, 
-        key should be cited in markdown as cite\`key\`/\@key, optionally comma separated keys.
+        r"""Set citations from dictionary or string with content like `\@key: citation value` on their own lines, 
+        key should be cited in markdown as cite\`key\` / \@key, optionally comma separated keys.
         `mode` for citations should be one of ['inline', 'footnote']. Number of columns in citations are determined by hl`Slides.settings.layout(..., ncol_refs=N)`.
 
         ```python
@@ -481,6 +492,7 @@ class Slides(BaseSlides,metaclass=Singleton):
         ::: note
             - You should set citations in start if using voila or python script. Setting in start in notebook is useful as well.
             - Citations are replaced with new ones, so latest use of this function reprsents available citations.
+            - Makrdown equivalent of this function is a citation block only supported in `Slides.sync_with_file`'s context.
         """
         if isinstance(data, dict):
             self._set_ctns(data)
@@ -498,7 +510,7 @@ class Slides(BaseSlides,metaclass=Singleton):
         
         if self._cite_mode != mode:
             self._cite_mode = mode # Update first as they need in display update
-            self._set_unsynced() # will go synced after rerun 
+            self._set_unsynced(True) # will go synced after rerun 
         
         # Finally write resources to file in assets
         with self.set_dir(self._assets_dir):
@@ -548,9 +560,6 @@ class Slides(BaseSlides,metaclass=Singleton):
         self.this._toc_args = (title, highlight)
         display(self.this._reset_toc()) # Must to have metadata there
 
-    def goto_button(self, text, **kwargs):
-        raise DeprecationWarning("Use `Slides.link` instead of `goto_button` to create links to other slides in a streamlined way.")
-
     def link(self, label, back_label=None, icon=None, back_icon=None):
         r"""Create a link to jump to another slide. Use `label` for link text 
         and `back_label` for the  optional text on the target slide if need to jump back.
@@ -727,11 +736,6 @@ class Slides(BaseSlides,metaclass=Singleton):
         slide_number = int(line[0])  # First argument is slide number
 
         if "-m" in line[1:]:
-            clear_citations = lambda m: '' if synced else self.error("ValueError", 
-                "citations block is only allowed inside synced markdown file! Use `Slides.set_citations` otherwise.\n"
-                + m.group().replace('`','\`')
-            ).value
-            cell = re.sub(r'```citations(.*?)\n```',clear_citations, cell, flags=re.DOTALL | re.MULTILINE) 
             if any(map(lambda v: re.search(r"^\s*--\s*$",v, flags=re.DOTALL | re.MULTILINE), 
                 (re.findall(r'```multicol(.*?)\n```', cell, flags=re.DOTALL | re.MULTILINE) or [''])
                 )):
@@ -780,7 +784,7 @@ class Slides(BaseSlides,metaclass=Singleton):
         Can use in place of `write` commnad for strings.
         When using `%xmd`, you can pass variables as \%{var} (slash for escap here) which will substitute HTML representation
         if no other formatting specified.
-        Inline columns are supported with stack`C1 | C2` syntax."""
+        Inline columns are supported with stack`C1 || C2` syntax."""
         if cell is None:
             return parse(line, returns = False)
         else:
