@@ -541,7 +541,7 @@ def center(obj):
     
 def html(tag, children = None,css_class = None,**node_attrs):
     """Returns html node with given children and node attributes like style, id etc. If an ttribute needs '-' in its name, replace it with '_'.     
-    `tag` can be any valid html tag name. A `tag` that ends with `/` will be self closing e.g. `hr/` will be `<hr/>`.  Empty tag gives unwrapped children.
+    `tag` can be any valid html tag name. A `tag` that ends with ` / ` will be self closing e.g. ` hr/ ` will be `<hr/>`.  Empty tag gives unwrapped children.
     `children` expects:
     
     - If None, returns node such as 'image' -> <img alt='Image'></img> and 'image/' -> <img alt='Image' />
@@ -622,7 +622,7 @@ def line(length=5, color='var(--fg1-color)',width=1,style='solid'):
 def textbox(text, **css_props):
     """Formats text in a box for writing e.g. inline refrences. `css_props` are applied to box and `-` should be `_` like `font-size` -> `font_size`. 
     `text` is not parsed to general markdown i.e. only bold italic etc. applied, so if need markdown, parse it to html before. You can have common CSS for all textboxes using class `text-box`."""
-    css_props = {'display':'inline-block','white-space': 'pre', **css_props} # very important to apply text styles in order
+    css_props = {'display':'inline','white-space': 'pre', **css_props} # very important to apply text styles in order
     return XTML(f'<span class="text-box" {_inline_style(css_props)}>{text}</span>')  # markdown="span" will avoid inner parsing
 
 def alert(text):
@@ -636,22 +636,23 @@ def color(text,fg='var(--accent-color, blue)',bg=None):
 def stack(objs, sizes=None, vertical=False, css_class=None, **css_props):
     """Stacks given objects in a column or row with given sizes. 
     
-    - objs: list/tuple of objects or a markdown string with '|' as separator.
+    - objs: list/tuple of objects or a markdown string with '||' as separator.
     - sizes: list/tuple of sizes(int, float) for each object, if not given, all objects will have equal size.
     - vertical: bool, to stack objects vertically or horizontally, default is horizontal.
     - css_class: str, to add a class to the container div.
     - css_props: dict, applied to the container div, so you can control top layout.
     """
     if isinstance(objs, str):
-        objs = [v.strip() for v in objs.replace(r'\|','COL-SEP-PIPE').split('|')] # Split by pipe if given a string
+        objs = [v.strip() for v in objs.replace(r'\|','COL-SEP-PIPE').split('||')] # Split by pipes if given a string
     
     if not isinstance(objs, (list, tuple)):
         raise TypeError(f'objs should be a markdown string, list or tuple of objects, got {type(objs)}')
     
-    kwargs = {'display': 'flex', 'flex-direction': 'column' if vertical else 'row', 
-        **css_props, # do not allow to override display and flex-direction
-        'gap': '0.25em','padding':'0.25em',
-    }
+    kwargs = {
+        'gap': '0.25em', 
+        **css_props, # do not allow to override display and flex-direction, so come later
+        'display': 'flex', 'flex-direction': 'column' if vertical else 'row', 
+    } 
     if sizes is not None:
         if not isinstance(sizes, (list, tuple)):
             raise TypeError(f'sizes should be a list or tuple of sizes, got {type(sizes)}')
@@ -660,14 +661,14 @@ def stack(objs, sizes=None, vertical=False, css_class=None, **css_props):
         for size in sizes:
             if not isinstance(size, (int, float)):
                 raise TypeError(f'size should be an int or float, got {type(size)}')
-        sizes = [{'flex': f'{size} 1'} for size in sizes] # Convert to flex style dicts
+        sizes = [{'flex': f'{size} 1','min-width':0} for size in sizes] # Convert to flex style dicts
     else:
-        sizes = [{'flex': '1 1'}] * len(objs) # default sizes if not given
+        sizes = [{'flex': '1 1','min-width':0}] * len(objs) # default sizes if not given
     
     return html('div', [
         html('div', htmlize(obj).replace('COL-SEP-PIPE','|'), style=size) 
         for obj, size in zip(objs, sizes)
-    ], style = kwargs, css_class=css_class) 
+    ], style = kwargs, css_class=(f'{css_class or ""} {"" if vertical else "columns"}').strip()) 
     
 
 def table(data, headers = None, widths=None):
@@ -739,7 +740,7 @@ def sig(callable,prepend_str = None):
         _sig = f'<b>{callable.__name__}</b>'
         if prepend_str: 
             _sig = f'{prepend_str}.{_sig}' 
-        _sig = f'<span class="sig">{_sig}</span>' + hl(str(inspect.signature(callable)))
+        _sig = f'<span class="sig">{_sig}</span>' + hl(str(inspect.signature(callable))).value
         return XTML(_sig)
     except:
         raise TypeError(f'Object {callable} is not a callable')
