@@ -99,7 +99,7 @@ _special_funcs = {
     "styled": "style objects with CSS classes and inline styles",
     "zoomable": "zoom a block of html when hovered",
     "center": r"text or \%{variable}", # should after most of the functions
-    "stack": r"text separated by |, like stack[(1,2,1),**css_props]\\`C1 | C2 | C3\\`",
+    "stack": r"text separated by ||, like stack[(1,2,1),**css_props]\\`C1 || C2 || C3\\`",
 }
 
 def error(name, msg):
@@ -163,10 +163,14 @@ def resolve_objs_on_slide(xmd_instance, slide_instance, text_chunk):
         if i == len(all_matches): # only last one to take effect
             slide_instance.this.yoffset(int(match))
     
+    # @key! for inline citations even in footnote mode, do before others
+    text_chunk = re.sub(r"@(?:[A-Za-z_]\w*)!", lambda m: slide_instance._nocite(m.group()[1:-1]), text_chunk)
+    
     # @key -> cite`key` before other stuff
     at_key_pattern = re.compile(r'''
         (?<!\\) # negative lookbehind: don't match if there's a backslash
         (?<!\w) # Don't match if a word before so example@google.com is safe
+        (?<!\`) # Don't match keys inside backticks
         @(?:[A-Za-z_]\w*)(?:\s*,\s*@(?:[A-Za-z_]\w*))*   # @key, @key4 (citation) or single @key
     ''', re.VERBOSE)
     for match in at_key_pattern.findall(text_chunk):
@@ -199,7 +203,7 @@ def resolve_objs_on_slide(xmd_instance, slide_instance, text_chunk):
     for match in all_matches:
         slide_instance.this._set_refs = False # already added here
         _cits = ''.join(v.value for v in sorted(slide_instance.this._citations.values(), key=lambda x: x._id))
-        out = f"<div class='Citations' style='column-count: {match} !important;'>{_cits}</div>"
+        out = f"<div class='Citations text-small' style='column-count: {match} !important;'>{_cits}</div>"
         text_chunk = text_chunk.replace(f"refs`{match}`", out, 1)
 
     return text_chunk
@@ -268,12 +272,41 @@ del TagFixer
 
 # This shoul be outside, as needed in other modules
 def resolve_included_files(text_chunk):
-    "Markdown files added by include`file.md` should be inserted as plain."
-    all_matches = re.findall(r"include\`(.*?)\`", text_chunk, flags = re.DOTALL)
+    "Markdown files added by include`file.md[start:end]` should be inserted as plain."
+    all_matches = re.findall(r"include\`(.*?)\`", text_chunk, flags=re.DOTALL)
     for match in all_matches:
-        with open(match, "r", encoding="utf-8") as f:
-            text = "\n" + f.read() + "\n" 
-            text_chunk = text_chunk.replace(f"include`{match}`", text, 1)
+        # Parse match into file path and range
+        range_match = re.search(r'\[(.*?)\]$', match)
+        if range_match:
+            filepath = match[:range_match.start()].strip()
+            range_str = range_match.group(1).strip()
+            
+            start, end = None, None
+            try:
+                if ':' in range_str:
+                    start_str, end_str = range_str.split(':', 1)
+                    start = int(start_str.strip()) - 1 if start_str.strip() else None
+                    end = int(end_str.strip()) if end_str.strip() else None
+                elif range_str: # single line number
+                    start = int(range_str) - 1
+                    end = start + 1
+            except (ValueError, IndexError):
+                # Invalid range, treat whole match as filename
+                filepath = match
+                start, end = None, None
+        else:
+            filepath = match
+            start, end = None, None
+
+        try:
+            with open(filepath, "r", encoding="utf-8") as f:
+                lines = f.readlines()[slice(start,end)]
+                text = "\n" + "".join(lines) + "\n"
+                text_chunk = text_chunk.replace(f"include`{match}`", text, 1)
+        except Exception as e:
+            err_msg = error('Exception', f'Could not include file {filepath!r}:\n{e}').value
+            text_chunk = text_chunk.replace(f"include`{match}`", err_msg, 1)
+
     return text_chunk
 
 class XMarkdown(Markdown):
@@ -285,6 +318,14 @@ class XMarkdown(Markdown):
         self._fmt_ns = {} # provided by fmt
         self._returns = True
         self._slides = get_slides_instance()
+        self._nested = False # checks if using _parse in nested manner
+    
+    @property
+    def _wr(self):
+        if not hasattr(self, '_wr_imported'):
+            from . import writer # avoid cyclic, but import once
+            self._wr_imported = writer
+        return self._wr_imported
 
     def _extract_class(self, header):
         header = re.sub(r"\.(\d)",r"~%&!~\1", header) # Avoid .1 like things for cols
@@ -333,9 +374,10 @@ class XMarkdown(Markdown):
                     outputs.extend(out)
                 elif out: # Some syntax like section on its own line can leave empty block later
                     outputs.append(XTML(out))
-
-        self._vars = {} # reset at end to release references
-        self._fmt_ns = {} # reset back at end
+        
+        if not self._nested: # we need to keep these if nested parsing
+            self._vars = {} # reset at end to release references
+            self._fmt_ns = {} # reset back at end
 
         if returns:
             content = ""
@@ -343,28 +385,31 @@ class XMarkdown(Markdown):
                 if isinstance(out, XTML):
                     content += out.value 
                 else:
-                    from .writer import _fmt_html
-                    content += _fmt_html(out) # Rich content from python execution and Writer 
+                    content += self._wr._fmt_html(out) # Rich content from python execution and Writer 
             return content
         else:
             return display(*outputs)
-
-    def _resolve_nested(self, text_chunk):
+    
+    def _parse_nested(self, xmd, returns=True):
         old_returns = self._returns
+        self._nested = True
         try:
-            # match func`?text?` to parse text and return func`html_repr`
-            all_matches = re.findall(
-                r"\`\?(.*?)\?\`", text_chunk, flags=re.DOTALL | re.MULTILINE
-            )
-            for match in all_matches:
-                repr_html = self._parse(match, returns = True)
-                repr_html = re.sub(
-                    "</p>$", "", re.sub("^<p>", "", repr_html)
-                )  # Remove <p> and </p> tags at start and end
-                text_chunk = text_chunk.replace(f"`?{match}?`", f"`{repr_html}`", 1)
+            out = self._parse(textwrap.dedent(xmd), returns=returns) # allows nesting via indent
         finally:
             self._returns = old_returns
+            self._nested = False
+        return out
 
+    def _resolve_nested(self, text_chunk):
+        def repl(m: re.Match): # Remove <p> and </p> tags at start and end, also keep backtick
+            return f'`{re.sub("^<p>|</p>$", "", self._parse_nested(m.group(1), returns = True))}`' 
+
+        # match legacy func`?text?` to parse text and return func`html_repr`
+        text_chunk = re.sub(r"\`\?(.*?)\?\`", repl, text_chunk, flags=re.DOTALL | re.MULTILINE)
+        # Now match neseted `// //` upto many levels
+        for depth in range(4,1,-1): # `////, `///, `// at least two slashes
+            op, cl = '/'*depth, '/'*depth
+            text_chunk = re.sub(rf"\`{op}(.*?){cl}\`", repl, text_chunk, flags=re.DOTALL | re.MULTILINE)
         return text_chunk
 
     def _parse_block(self, block):
@@ -374,6 +419,13 @@ class XMarkdown(Markdown):
         if "multicol" in line:
             out = self._parse_multicol(data, line, _class)
             return [XTML(out)] if isinstance(out, str) else out # Writer under frames
+        elif "citations" in line:
+            return [error("ValueError", 
+                f"citations block is only parsed inside synced markdown file! "
+                f"Use `Slides.set_citations` otherwise.\n```{block}\n```"
+            )]
+        elif "md-" in line:
+            return self._parse_md_src(data, line, _class)
         else:
             out = XTML() # empty placeholder
             try:
@@ -383,10 +435,42 @@ class XMarkdown(Markdown):
                 out.data = super().convert(f'```{block}\n```') # Let other extensions parse block
             
             return [out,] # list 
+        
+    def _parse_md_src(self, data, line, _class):
+        data = textwrap.dedent(data) # dedent allows embeding nested stuff like multicol, it will be parsed in stack
+        pos, *collapse = line.strip()[3:].split()
+        _req_pos = "before,after,left,right"
+        if pos not in _req_pos:
+            return [error("ValueError",f"The suffix after md- should be {_req_pos}, got {pos}")]
+        if collapse and collapse[0] not in ("","-c"):
+            return [error("ValueError",f"Only swicth -c expected if given to collapse code after md-[suffix] other than CSS class, got {collapse[0]}")]
+        src = XTML(_highlight(data, "markdown", name=False if collapse else None, css_class=f"md-src {_class}"))
+        if collapse:
+            src = XTML(f"<details><summary>Show Markdown Source</summary>\n{src}\n</details>")
+        
+        if self._returns: # display context
+            outs = [XTML(self._parse_nested(data, returns=True))]
+        else:
+            with capture_content() as cap:
+                self._parse_nested(data, returns=False)
+            outs = cap.outputs
+        
+        if pos in ("before","after"):
+            return [src, *outs] if pos == "before" else [*outs, src]
+        
+        if self._returns: 
+            objs = (src, outs[0]) if pos == "left" else (outs[0], src) # return mode, len(outs) == 1
+            output = "\n".join(f"<div style='width:50%;overflow-x:auto;height:auto;position:relative;'>{v}</div>" for v in objs)
+            return [XTML(f'<div class="columns md-block" style="display:flex;">\n{output}\n</div>')] # display for notebook
+        
+        with capture_content() as cap:
+            self._wr.write(*((src, outs) if pos == "left" else (outs, src)), css_class="md-block")
+        return cap.outputs
+
 
     def _parse_multicol(self, data, header, _class):
         "Returns parsed block or columns or code, input is without ``` but includes langauge name."
-        cols = data.split("+++")  # Split by columns
+        cols = re.split("^\+\+\+\s*$", data, flags=re.MULTILINE)  # Split by columns, allow nesetd blocks by indents
         if header.strip() == "multicol":
             widths = [100/len(cols) for _ in cols]
         else:
@@ -404,27 +488,34 @@ class XMarkdown(Markdown):
                     return error('TypeError',f"{w} is not a positive integer or float value in {header!r}").value
 
             widths = [float(w) for w in widths]
+            widths = [100*w/sum(widths) for w in widths] # allow relative column widths
         
-        # Under slides and any display context, multicol should return Writer 
-        if self._slides and not self._returns:
+        # Under any display context
+        if not self._returns:
+            cap_cols = []
+            for col in cols:
+                with capture_content() as cap:
+                    self._parse_nested(col,returns=False)
+                cap_cols.append(cap)
+
             with capture_content() as cap:
-                self._slides.write(*[self.convert(col) for col in cols], widths=widths, css_class=_class)
+                self._wr.write(*cap_cols, widths=widths, css_class=_class)
             
             return cap.outputs
         
-        cols = [self.convert2str(col) for col in cols]
+        cols = [self._parse_nested(col,returns=True) for col in cols]
         if len(cols) == 1: # do not return before checking widths and adding extra cols if needed
             return f'<div class={_class}">{cols[0]}</div>' if _class else cols[0]
 
         cols = "".join(
-            [f"""<div style='width:{w}%;overflow-x:auto;height:auto'>{col}</div>"""
+            [f"""<div style='width:{w}%;overflow-x:auto;height:auto;position:relative;'>{col}</div>"""
                 for col, w in zip(cols, widths)])
 
-        return f'<div class="columns {_class}">{cols}\n</div>'
+        return f'<div class="columns {_class}" style="display:flex;">{cols}\n</div>' # display for notebook
     
     def convert(self, text):
         """Replaces variables with placeholder after conversion to respect all other extensions.
-        Returns str or list of outputs based on context. To ensure str, use `self.convert2str`.
+        Returns str or list of outputs based on context. To ensure str, use `parse(..., returns=True)`.
         """
         text = resolve_included_files(text)
         text = re.sub(r"\\\`", "&#96;", text)  # Escape backticks after files added
@@ -438,7 +529,8 @@ class XMarkdown(Markdown):
             text = re.sub("ESCAPED_AT_SYMBOL","@", resolve_objs_on_slide(
                 self, self._slides, re.sub(r"\\@","ESCAPED_AT_SYMBOL", text) # escape \@cite_key before resolving objects on slides
             ))  # Resolve objects in xmd related to current slide
-
+        text = re.sub(r"\\@","@", text) # same stuff when goes off slides, should be correct
+        
         # Resolve <link:label:origin text> and <link:label:target text?>
         text = re.sub(r"<link:([\w\d-]+):origin\s*(.*?)>", r"<a href='#target-\1' id='origin-\1' class='slide-link'>\2</a>", text)
         text = re.sub(r"<link:([\w\d-]+):target\s*(.*?)>", r"<a href='#origin-\1' id='target-\1' class='slide-link'>\2</a>", text)
@@ -452,14 +544,6 @@ class XMarkdown(Markdown):
                 self._sub_vars(text) # sub vars before conversion
             ))
     
-    def convert2str(self, text):
-        "Ensures that output will be a str."
-        outputs = self.convert(text)
-        if isinstance(outputs, list): # From Variables
-            # formats handled automatically for most of objects, as we are returning strings anyhow
-            return ''.join([f"{out}" for out in outputs])
-        return outputs
-    
     def _var_info(self, match_str):
         try: 
             obj = self._vars[match_str]
@@ -542,8 +626,8 @@ class XMarkdown(Markdown):
 
         for func in _special_funcs.keys():
             all_matches = re.findall(
-                rf"{func}(\[.*?\])?\`(.*?)\`", html_output, flags=re.DOTALL | re.MULTILINE
-            ) # returns two matches always
+                rf"(?<!\`){func}(\[.*?\])?\`(.*?)\`", html_output, flags=re.DOTALL | re.MULTILINE
+            ) # returns two matches always, don't match like `image` or and keep trying forward for no reason
             for m1, m2 in all_matches:
                 _func = getattr(utils, func)
                 arg0 = m2.strip() # avoid spaces in this
@@ -564,17 +648,6 @@ class XMarkdown(Markdown):
                         )
                     html_output = html_output.replace(f"{func}{m1}`{m2}`", self._handle_var(_out), 1)
 
-        if all_cols := re.findall(
-            r"\|\|(\s*\d*\.?\d*\s*)(.*?)\|\|(.*?)\|\|", html_output, flags=re.DOTALL | re.MULTILINE
-            ):
-            _sig = str(inspect.signature(utils.stack)).split(',', 1)[1].strip(' )') # get signature without first argument
-            for width, *cols in all_cols:
-                info = error("Exception",
-                    f"Use stack[{_sig}]` C1 | C2 | ...` syntax instead of \n||{width}{cols[0]}||{cols[1]}||\n "
-                    "to have better control over number of columns/rows and their sizes."
-                ).value # show error if used
-                html_output = html_output.replace(f"||{width}{cols[0]}||{cols[1]}||", self._handle_var(info), 1)
-
         return re.sub(r"&(?:amp;)?#96;","`", html_output)  # return in main scope
 
 
@@ -597,7 +670,7 @@ def parse(xmd, returns = False):
      ```python
      # This will not be executed, only shown
      ```
-     stack`Inline-column A | Inline-column B`
+     stack`Inline-column A || Inline-column B`
     ```
 
     ::: note-info
@@ -609,7 +682,7 @@ def parse(xmd, returns = False):
         - There are special CSS classes `jupyter-only` and `export-only` that control appearance of content in different modes.
 
     ::: note-warning
-        Nested blocks are not supported.
+        Nested blocks are supported via indentation in `md-[before,after,left,right]` and `multicol`, but may be broken in display contexts.
 
     ::: note-info
         - Find special syntax to be used in markdown by `Slides.xmd_syntax`.
